@@ -495,7 +495,7 @@ class ms2Spectrum:
         print("Precursor m/z: " + str(np.round(self.precsMz, decimals=4)))
         print("rt: " + str(np.round(self.rt, decimals=2)) + " min.")
         if showMS2:
-            print('prodMz: ' + str(np.round(self.prodMz, decimals=0)))
+            print('prodMz: ' + str(np.round(self.prodMz, decimals=4)))
             print("Intensity: " + str(np.round(self.prodInt, decimals=0)))
 
 
@@ -603,8 +603,7 @@ def dotProd(ms2A, ms2B, mzTol=0.02):
     Parameters
     ----------------------------------------------------------
     ms2A: ms2Spectrum object
-        The first MS2. For reverse dot product, ms2A is the 
-        reference spectrum.
+        The first MS2.
     ms2B: ms2Spectrum object
         The second MS2.
     mzTol: float
